@@ -276,7 +276,7 @@ class _Agent:
             self._allowed_devices.append(self._pending_transfer['address'])
             GObject.timeout_add(60000, self._allowed_devices.remove, self._pending_transfer['address'])
         else:
-            self._agent.reply_rejected()
+            self._agent.reply_rejected(None)
 
     def _on_authorize(self, _agent, transfer_path, address=None, filename=None, size=None):
         if address and filename and size:
@@ -284,6 +284,7 @@ class _Agent:
             # FIXME: /tmp is only the default. Can we get the actual root
             # directory from stand-alone obexd?
             root = '/tmp'
+            name = _("Unknown device")
         else:
             # BlueZ 5 integrated obexd
             transfer = Transfer(transfer_path)
@@ -292,23 +293,26 @@ class _Agent:
             address = session.address
             filename = transfer.name
             size = transfer.size
-            name = subprocess.check_output(["hcitool", "name", session.address]).strip()
+            name = subprocess.check_output(["hcitool", "name", session.address]).decode("utf-8").strip()
 
         self._pending_transfer = {'transfer_path': transfer_path, 'address': address, 'root': root,
                                   'filename': filename, 'size': size, 'name': name}
 
+        try:
+            name = str("<b>%s</b>" % name)
+            filename = str("<b>%s</b>" % filename)
+        except Exception as e:
+            print (e)
 
         # This device was not allowed yet -> ask for confirmation
         if address not in self._allowed_devices:
             self._notification = NotificationBubble(_("Incoming file over Bluetooth"),
-                _("Incoming file %(0)s from %(1)s") % {"0": "<b>" + filename + "</b>",
-                                                       "1": "<b>" + name + "</b>"},
+                _("Incoming file %(0)s from %(1)s") % {"0": filename, "1": name},
                 30000, [["accept", _("Accept"), "help-about"], ["reject", _("Reject"), "help-about"]], self._on_action)
         # Device was already allowed, larger file -> display a notification, but auto-accept
         elif size > 350000:
             self._notification = NotificationBubble(_("Receiving file"),
-                _("Receiving file %(0)s from %(1)s") % {"0": "<b>" + filename + "</b>",
-                                                        "1": "<b>" + name + "</b>"})
+                _("Receiving file %(0)s from %(1)s") % {"0": filename, "1": name})
             self._on_action(self._notification, 'accept')
         # Device was already allowed. very small file -> auto-accept and transfer silently
         else:
@@ -317,7 +321,7 @@ class _Agent:
 
     def _on_cancel(self, agent):
         self._notification.close()
-        agent.reply_cancelled()
+        agent.reply_cancelled(None)
 
 
 class TransferService():
@@ -398,17 +402,24 @@ class TransferService():
         dest = os.path.join(dest_dir, filename)
         shutil.move(src, dest)
 
+        attr = attributes['name']
+        try:
+            filename = str("<b>%s</b>" % filename)
+            attr = str("<b>%s</b>" % attr)
+        except Exception as e:
+            print(e)
+
         if success:
             n = NotificationBubble(_("File received"),
                              _("File %(0)s from %(1)s successfully received") % {
-                                 "0": "<b>" + filename + "</b>",
-                                 "1": "<b>" + attributes['name'] + "</b>"})
-            self._add_open(n, "Open", dest)
+                                 "0": filename,
+                                 "1": attr})
+            self._add_open(n, _("Open"), dest)
         elif not success:
             NotificationBubble(_("Transfer failed"),
                          _("Transfer of file %(0)s failed") % {
-                             "0": "<b>" + filename + "</b>",
-                             "1": "<b>" + attributes['name'] + "</b>"})
+                             "0": filename,
+                             "1": attr})
 
             if attributes['size'] > 350000:
                 self._normal_transfers -= 1
@@ -426,13 +437,13 @@ class TransferService():
                              ngettext("Received %d file in the background", "Received %d files in the background",
                                       self._silent_transfers) % self._silent_transfers)
 
-            self._add_open(n, "Open Location", SHARED_PATH)
+            self._add_open(n, _("Open"), SHARED_PATH)
         else:
             n = NotificationBubble(_("Files received"),
                              ngettext("Received %d more file in the background",
                                       "Received %d more files in the background",
                                       self._silent_transfers) % self._silent_transfers)
-            self._add_open(n, "Open Location", SHARED_PATH)
+            self._add_open(n, _("Open"), SHARED_PATH)
 
 class ObexdNotFoundError(Exception):
     pass
@@ -712,11 +723,11 @@ class AgentManager(Base):
         self._interface.UnregisterAgent(agent_path, reply_handler=on_unregistered, error_handler=on_unregister_failed)
 
 if __name__ == '__main__':
-    settings = Gio.Settings("org.blueberry")
+    settings = Gio.Settings(schema="org.blueberry")
     if settings.get_boolean("obex-enabled"):
         try:
             dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
-            mainloop = GObject.MainLoop()
+            mainloop = GLib.MainLoop()
             service = TransferService()
             service.load()
             cont = True
